summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/skills2.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/skills2.cc')
-rw-r--r--crawl-ref/source/skills2.cc2
1 files changed, 1 insertions, 1 deletions
diff --git a/crawl-ref/source/skills2.cc b/crawl-ref/source/skills2.cc
index a670ccf232..2c8f655f44 100644
--- a/crawl-ref/source/skills2.cc
+++ b/crawl-ref/source/skills2.cc
@@ -2110,7 +2110,7 @@ int calc_hp(bool real_hp)
}
}
// frail and robust mutations
hitp *= (10 + player_mutation_level(MUT_ROBUST)
+ you.attribute[ATTR_DIVINE_ROBUSTNESS]
- player_mutation_level(MUT_FRAIL));
@@ -2110,7 +2110,7 @@ int calc_hp(bool real_hp)
}
}
- // frail and robust mutations
+ // frail and robust mutations, and divine robustness
hitp *= (10 + player_mutation_level(MUT_ROBUST)